@@ -2,7 +2,7 @@ module ReverseMarkdown
   module Converters
     class Div < Base
       def convert(node, state = {})
-        "\n" << treat_children(node, state) << "\n"
+        +"\n" << treat_children(node, state) << "\n"
       end
     end
 
