@@ -3,7 +3,7 @@ module ReverseMarkdown
     class Ol < Base
       def convert(node, state = {})
         ol_count = state.fetch(:ol_count, 0) + 1
-        "\n" << treat_children(node, state.merge(ol_count: ol_count))
+        +"\n" << treat_children(node, state.merge(ol_count: ol_count)) << "\n"
       end
     end
 
